==> ui-18.4.0.tgz: package/components/fab/Fab.js <==
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { isUndefined } from 'lodash';
import React from 'react';
import { getClassName } from '@react-devui/utils';
import { useDValue } from '../../hooks';
import { cloneHTMLElement, registerComponentMate } from '../../utils';
import { useComponentConfig, usePrefixConfig } from '../root';
import { DFabBacktop } from './FabBacktop';
import { DFabButton } from './FabButton';
const { COMPONENT_NAME } = registerComponentMate({ COMPONENT_NAME: 'DFab' });
export const DFab = (props) => {
    const _a = useComponentConfig(COMPONENT_NAME, props), { children, dExpand, dList, onExpandChange } = _a, restProps = __rest(_a, ["children", "dExpand", "dList", "onExpandChange"]);
    //#region Context
    const dPrefix = usePrefixConfig();
    //#endregion
    const [expand, changeExpand] = useDValue(false, dExpand, onExpandChange);
    return (_jsxs("div", Object.assign({}, restProps, { className: getClassName(restProps.className, `${dPrefix}fab`) }, { children: [cloneHTMLElement(children, {
                className: getClassName(children.props.className, { 'is-expand': expand }),
                onClick: (e) => {
                    var _a, _b;
                    (_b = (_a = children.props).onClick) === null || _b === void 0 ? void 0 : _b.call(_a, e);
                    if (!isUndefined(dList)) {
                        changeExpand((draft) => !draft);
                    }
                },
            }), expand &&
                dList &&
                dList.map(({ placement, actions }, key) => (_jsx("div", Object.assign({ className: getClassName(`${dPrefix}fab__actions`, `${dPrefix}fab__actions--${placement}`) }, { children: React.Children.map(actions, (action, index) => cloneHTMLElement(action, {
                        className: getClassName(action.props.className, `${dPrefix}fab__action`),
                        style: Object.assign(Object.assign({}, action.props.style), { animationDelay: `${index * 33}ms` }),
                        onClick: (e) => {
                            var _a, _b;
                            (_b = (_a = action.props).onClick) === null || _b === void 0 ? void 0 : _b.call(_a, e);
                            changeExpand(false);
                        },
                    })) }), key)))] })));
};
DFab.Button = DFabButton;
DFab.Backtop = DFabBacktop;

==> ui-18.5.7.tgz: package/components/fab/Fab.js <==
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { isUndefined } from 'lodash';
import React from 'react';
import { getClassName } from '@react-devui/utils';
import { useDValue } from '../../hooks';
import { cloneHTMLElement, registerComponentMate } from '../../utils';
import { useComponentConfig, usePrefixConfig } from '../root';
import { DFabBacktop } from './FabBacktop';
import { DFabButton } from './FabButton';
const { COMPONENT_NAME } = registerComponentMate({ COMPONENT_NAME: 'DFab' });
export const DFab = (props) => {
    const _a = useComponentConfig(COMPONENT_NAME, props), { children, dExpand, dList, onExpandChange } = _a, restProps = __rest(_a, ["children", "dExpand", "dList", "onExpandChange"]);
    //#region Context
    const dPrefix = usePrefixConfig();
    //#endregion
    const [expand, changeExpand] = useDValue(false, dExpand, onExpandChange);
    return (_jsxs("div", Object.assign({}, restProps, { className: getClassName(restProps.className, `${dPrefix}fab`) }, { children: [cloneHTMLElement(children, {
                className: getClassName(children.props.className, { 'is-expand': expand }),
                onClick: (e) => {
                    var _a, _b;
                    (_b = (_a = children.props).onClick) === null || _b === void 0 ? void 0 : _b.call(_a, e);
                    if (!isUndefined(dList)) {
                        changeExpand((draft) => !draft);
                    }
                },
            }), expand &&
                dList &&
                dList.map(({ placement, actions }, key) => (_jsx("div", Object.assign({ className: getClassName(`${dPrefix}fab__actions`, `${dPrefix}fab__actions--${placement}`) }, { children: React.Children.map(placement === 'right' || placement === 'bottom' ? actions : [...actions].reverse(), (action, index) => cloneHTMLElement(action, {
                        className: getClassName(action.props.className, `${dPrefix}fab__action`),
                        style: Object.assign(Object.assign({}, action.props.style), { animationDelay: `${(placement === 'right' || placement === 'bottom' ? index : actions.length - 1 - index) * 33}ms` }),
                        onClick: (e) => {
                            var _a, _b;
                            (_b = (_a = action.props).onClick) === null || _b === void 0 ? void 0 : _b.call(_a, e);
                            changeExpand(false);
                        },
                    })) }), key)))] })));
};
DFab.Button = DFabButton;
DFab.Backtop = DFabBacktop;
